@@ -6,7 +6,9 @@
 #from mstrio.api import projects
 #from mstrio.api import objects as api_obj
 #from mstrio.project_objects import report
-from src.mstr_robotics import mstr_classes
+from mstr_classes import rep
+from mstr_classes import mstr_global
+from mstr_classes import get_conn
 from datetime import datetime
 import helper
 import pandas as pd
@@ -16,7 +18,7 @@ import json
 class open_conn():
 
     def standard_login(self,conn_det,project_id=None):
-        return mstr_classes.get_conn(self,conn_det=conn_det, project_id=project_id)
+        return get_conn(self,conn_det=conn_det, project_id=project_id)
 
 class prepare_mig_obj():
 
@@ -28,7 +30,7 @@ class prepare_mig_obj():
 
 class cubes:
     def __init__(self):
-        self.glob = mstr_classes.mstr_global()
+        self.glob = mstr_global
 
 
     def up_load_to_cube(self,conn,cube_upload_param):
@@ -45,8 +47,8 @@ class bld_short_cuts:
 
     def __init__(self):
         self.str=helper.str_func()
-        self.rep = mstr_classes.rep()
-        self.glob = mstr_classes.mstr_global()
+        self.rep = rep()
+        self.glob = mstr_global()
 
 
 
@@ -131,8 +133,8 @@ class get_change_log:
         self.short_cut_folder_id=None
 
         self.str=helper.str_func()
-        self.rep = mstr_classes.rep()
-        self.glob = mstr_classes.mstr_global()
+        self.rep = rep()
+        self.glob = mstr_global()
 
 
     def chg_rep_to_df(self,prompt_answ):
