@@ -12,11 +12,12 @@ from mstrio.object_management import folder
 import pandas as pd
 #import error_controller
 #from mstrio.utils.error_handlers import ErrorHandler
-from src.mstr_robotics import helper
-from src.mstr_robotics import logger
+from helper import str_func
+from logger import logger
 
+str_func=str_func
 log=logger
-@log.logger(err_name=f'Failed to open the a connection to the I-Server.')
+@log(err_name=f'Failed to open the a connection to the I-Server.')
 def get_conn(self, conn_det, project_id=None):
     if conn_det:
         conn = Connection(base_url=conn_det["base_url"], username=conn_det["username"],
@@ -40,19 +41,19 @@ class rep:
         self.i_reports = reports
         self.i_parser  =parser
 
-    @log.logger(err_name="Failed to open change log report")
+    @log(err_name="Failed to open change log report")
     def open_Instance(self, conn, project_id, report_id):
         #conn.headers["X-MSTR-ProjectID"] = project_id
         rep_instance = self.i_reports.report_instance(connection=conn, report_id=report_id)
         return rep_instance.json()["instanceId"]
 
-    @log.logger(err_name="Faile to set prompt answers for change log report")
+    @log(err_name="Faile to set prompt answers for change log report")
     def set_inst_prompt_ans(self, conn, project_id, report_id, instance_id, prompt_answ):
         prompt_answ_url = f'{conn.base_url}/api/reports/{report_id}/instances/{instance_id}/prompts/answers'
         ret_prompt_ans = conn.put(prompt_answ_url, data=prompt_answ)
         return ret_prompt_ans
 
-    @log.logger(err_name="Failed to execute or export change log report")
+    @log(err_name="Failed to execute or export change log report")
     def report_dict(self,conn,project_id,report_id, instance_id):
         report_ds=self.i_reports.report_instance_id(connection=conn, report_id=report_id, instance_id=instance_id)
         s = conn.get(f'{conn.base_url}/api/v2/reports/{report_id}/instances/{instance_id}/sqlView')
@@ -60,7 +61,7 @@ class rep:
         report_dict=self.i_parser.Parser(report_ds.json())._Parser__map_attributes(report_ds.json())
         return report_dict
 
-    @log.logger(err_name="Failed to read out objects from Folder")
+    @log(err_name="Failed to read out objects from Folder")
     def get_report_def(self,conn,report_id):
         return self.i_reports.report_definition(connection=conn,report_id=report_id)
 
@@ -68,15 +69,15 @@ class mstr_global:
 
     def __init__(self):
         self.i_api_obj=api_obj
-        self.str=helper.str_func()
+        self.str=str_func
         self.brow=browsing
 
-    @log.logger(err_name='Failed to find / open the given project')
+    @log(err_name='Failed to find / open the given project')
     def set_project_id(self,conn, project_id):
         conn.select_project(project_id)
         return conn
 
-    @log.logger(err_name="Failed to upload cube")
+    @log(err_name="Failed to upload cube")
     def cube_upload(self,conn, load_df, tbl_name, updatePolicy="REPLACE", folder_id=None, cube_name=None, mtdi_id=None):
         if mtdi_id == None:
             ds = SuperCube(connection=conn, name=cube_name)
@@ -91,18 +92,18 @@ class mstr_global:
         return ds.id
 
 
-    @log.logger(err_name="Failed to read out objects from Folder")
+    @log(err_name="Failed to read out objects from Folder")
     def get_folder_obj_l(self,conn,project_id,folder_id):
         i_folder = folder.Folder(connection=conn, id=folder_id)
         existing_obj_l = i_folder.get_contents(to_dictionary=True)
         return existing_obj_l
 
-    @log.logger(err_name="Failed to rename object")
+    @log(err_name="Failed to rename object")
     def _rename_object(self, object, new_name, desc_str):
         object.alter(name=new_name, description=desc_str)
         return
 
-    @log.logger(err_name="Didn't find object or could parse it")
+    @log(err_name="Didn't find object or could parse it")
     def get_object_info(self,conn,project_id, object_id,type):
         return self.i_api_obj.get_object_info(connection=conn,
                                        id=object_id,
@@ -110,12 +111,12 @@ class mstr_global:
                                        project_id=project_id)
 
 
-    @log.logger(err_name="No idea here. Pls. Check the error yourself :-)")
+    @log(err_name="No idea here. Pls. Check the error yourself :-)")
     def get_short_cut_obj(self, conn, project_id, object_id, type):
         short_cut_obj = object.Object(connection=conn, type=type, id=object_id)
         return short_cut_obj
 
-    @log.logger(err_name="Could delete object")
+    @log(err_name="Could delete object")
     def _delete_object(self,conn, project_id, existing_obj_l):
         self.set_project_id(conn=conn,project_id=project_id)
         for o in existing_obj_l:
@@ -123,7 +124,7 @@ class mstr_global:
                                                , object_type=o["type"])
         return
 
-    @log.logger(err_name="Failed to create short cut")
+    @log(err_name="Failed to create short cut")
     def _cr_short_cut(self,conn, object_id,object_type,folder_id):
         short_cut_folder_j = f'{{"folderId": "{folder_id}"}}'
         short_cut_url = f'{conn.base_url}/api/objects/{object_id}/type/{str(object_type)}/shortcuts'
@@ -137,10 +138,10 @@ class mstr_global:
             if f["name"] != proj_name:
                 path_s += f["name"] + "\\"
 
-        path_s = self.str._rem_last_char(path_s)
+        path_s =self.str._rem_last_char(self,path_s)
         return path_s
 
-    @log.logger(err_name="Project not found")
+    @log(err_name="Project not found")
     def get_project_name(self,conn,project_id):
         project_resp=conn.get(f'{conn.base_url}/api/projects')
         for p in project_resp.json():
@@ -187,7 +188,7 @@ class mstr_global:
 
         return [dict(t) for t in {tuple(d.items()) for d in rec_obj_l}]
 
-    @log.logger(err_name="Faild to read out with object infos")
+    @log(err_name="Faild to read out with object infos")
     def bld_obj_d(self, conn, obj_d, project_id):
         val_l = []
         obj_row_d = {"project_id":project_id,
